### Installation
The module, OR requires pandas module to function
This module is used to remove the tuples having outliers in the datset and generate outlier-free dataset.

Usages: python-outlier <InputDataFile> 
	
```sh
$ pip install python-outlier
$ python-outlier myData.csv
```
### License
MIT
### Author
Sahil Ahuja
